@@ -1,9 +1,9 @@
 package Sah::Schemas::Math;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-05-27'; # DATE
+our $DATE = '2021-07-19'; # DATE
 our $DIST = 'Sah-Schemas-Math'; # DIST
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 1;
 # ABSTRACT: Math-related Sah schemas
@@ -20,10 +20,29 @@ Sah::Schemas::Math - Math-related Sah schemas
 
 =head1 VERSION
 
-This document describes version 0.001 of Sah::Schemas::Math (from Perl distribution Sah-Schemas-Math), released on 2020-05-27.
+This document describes version 0.002 of Sah::Schemas::Math (from Perl distribution Sah-Schemas-Math), released on 2021-07-19.
 
 =head1 DESCRIPTION
 
+=head1 SAH SCHEMAS
+
+=over
+
+=item * L<math::complex|Sah::Schema::math::complex>
+
+Complex number.
+
+See also C<posfloat> for floats that are larger than 0.
+
+
+=back
+
+=head1 CONTRIBUTOR
+
+=for stopwords perlancar (on netbook-zenbook-ux305)
+
+perlancar (on netbook-zenbook-ux305) <perlancar@gmail.com>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Sah-Schemas-Math>.
@@ -56,7 +75,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
